@@ -1,6 +1,6 @@
 /* This file is part of webtexter
  *
- * Copyright (C) 2009 Thom Troy
+ * Copyright (C) 2011 Thom Troy
  *
  * WebTexter is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License (GPL) as published by
@@ -46,6 +46,7 @@
 #include <curl/curl.h>
 #include <curl/easy.h>
 #include "localisation.h"
+#include "he-about-dialog.h"
 
 
 /* Orientation functions modified from those in conboy and mbarcode.*/
@@ -422,6 +423,9 @@ some_page_func (GtkNotebook *nb,
 			GtkRadioButton *lowratevoip_but = GTK_RADIO_BUTTON(g_list_nth_data(pan, LOWRATEVOIP));
 			GtkRadioButton *otherbetamax_but = GTK_RADIO_BUTTON(g_list_nth_data(pan, OTHER_BETAMAX));
 			GtkRadioButton *websmsru_but = GTK_RADIO_BUTTON(g_list_nth_data(pan, WEBSMSRU));
+			GtkRadioButton *exetel_but = GTK_RADIO_BUTTON(g_list_nth_data(pan, EXETEL));
+			GtkRadioButton *pennytel_but = GTK_RADIO_BUTTON(g_list_nth_data(pan, PENNYTEL));
+
 
 			if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(o2_but)))
 				appsettings->provider = O2;
@@ -443,6 +447,10 @@ some_page_func (GtkNotebook *nb,
 				appsettings->provider = OTHER_BETAMAX;
 			if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(websmsru_but)))
 				appsettings->provider = WEBSMSRU;
+			if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(exetel_but)))
+				appsettings->provider = EXETEL;
+			if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(pennytel_but)))
+							appsettings->provider = PENNYTEL;
 
 			return TRUE;
 		}
@@ -459,6 +467,50 @@ some_page_func (GtkNotebook *nb,
 				appsettings->use_proxy_script = FALSE;
 			}
 
+
+			/*
+			 * Make the wizard more intuative by disabling or setting the context of pages based
+			 * on previous answers. This is currently only for the URL \ Proxy page
+			 */
+			GtkWidget *url_page;
+			url_page = gtk_notebook_get_nth_page (nb, 3);
+			GList *url_page_children = gtk_container_get_children(GTK_CONTAINER(url_page));
+
+			GtkWidget *url_label;
+			url_label = GTK_WIDGET(g_list_nth_data(url_page_children, 0));
+			HildonEntry *urlp_entry;
+			urlp_entry = HILDON_ENTRY(g_list_nth_data(url_page_children, 1));
+			GtkWidget *url_info_label;
+			url_info_label = GTK_WIDGET(g_list_nth_data(url_page_children, 2));
+
+			if(appsettings->provider == OTHER_BETAMAX)
+			{
+				gtk_label_set_text(GTK_LABEL(url_label), "Betamax URL");
+				gtk_label_set_text(GTK_LABEL(url_info_label),
+						"Please enter the URL of the sms page. \nThis is normally in the format \nhttps://www.provider.com/myaccount/sendsms.php");
+
+			}
+			else if(appsettings->provider == WEBSMSRU || appsettings->provider == BLUEFACE || appsettings->provider == EXETEL
+					|| appsettings->provider == PENNYTEL)
+			{
+				gtk_label_set_text(GTK_LABEL(url_label), "Ignore Setting");
+				gtk_label_set_text(GTK_LABEL(url_info_label), "Please press next.");
+				gtk_editable_set_editable(GTK_EDITABLE(urlp_entry), FALSE);
+			}
+			else if(appsettings->use_proxy_script)
+			{
+				gtk_label_set_text(GTK_LABEL(url_label), "Cabbage Script Address (http://...)");
+				gtk_label_set_text(GTK_LABEL(url_info_label), "Enter the cabbage script address");
+			}
+			else
+			{
+				gtk_label_set_text(GTK_LABEL(url_label), "Ignore Setting");
+				gtk_editable_set_editable(GTK_EDITABLE(urlp_entry), FALSE);
+				gtk_label_set_text(GTK_LABEL(url_info_label), "Please press next.");
+			}
+
+
+
 			return TRUE;
 		}
 		case 3:
@@ -506,19 +558,16 @@ some_page_func (GtkNotebook *nb,
 
 void aboutButton_clicked (GtkButton* button, AppData *appdata)
 {
-	/*
-	 * TODO Should add contact info
-	 */
-	GtkWidget *about;
-	about = gtk_about_dialog_new();
+	he_about_dialog_present(GTK_WINDOW(appdata->messageWindow),
+	                        APP_NAME,
+	                        NULL,
+	                        APP_VER,
+	                        "Send web texts to Irish Mobile Operators \nand selected VoIP operators.",
+	                        "(c) 2010 Thom Troy",
+	                        "http://webtexter.garage.maemo.org",
+	                        "https://bugs.maemo.org/enter_bug.cgi?product=webtexter",
+	                        "https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=8DVWR56KA5F48");
 
-	gtk_about_dialog_set_program_name (GTK_ABOUT_DIALOG(about), APP_NAME);
-	gtk_about_dialog_set_version (GTK_ABOUT_DIALOG(about), APP_VER);
-	gtk_about_dialog_set_comments(GTK_ABOUT_DIALOG(about),
-			"Send web texts to Irish Mobile Operators and selected VoIP operators. VoIP operators currently supported are Blueface, Voipcheap, SMSdiscount and lowratevoip. It is possible to send directly to the operator or through web scripts compatible with cabbage (http://cabbagetexter.com)");
-
-	gtk_dialog_run(GTK_DIALOG(about));
-	gtk_widget_destroy(GTK_WIDGET(about));
 
 }
 
@@ -641,7 +690,7 @@ gint create_settings_wizard(AppData *appdata)
 	GtkWidget *proxy_info_label, *url_info_label, *savemsg_label, *savemsg_info_label;
 	GtkWidget *user_entry, *pass_entry, *number_entry, *proxy_url_entry;
 	GtkWidget *voda_button, *o2_button, *met_button, *three_button, *blueface_button, *voipcheap_button, *smsdiscount_button;
-	GtkWidget *lowratevoip_button, *other_betamax_button, *websmsru_button;
+	GtkWidget *lowratevoip_button, *other_betamax_button, *websmsru_button, *exetel_button, *pennytel_button;
 	GtkWidget *yes_proxy, *no_proxy;
 	GtkWidget *yes_savemsg, *no_savemsg;
 	GtkWidget *up_hbox, *prov_hbox, *proxy_hbox, *proxy_url_hbox, *savemsg_hbox;
@@ -666,17 +715,19 @@ gint create_settings_wizard(AppData *appdata)
 	char* lowrv = LOWRV_L;
 	char* otherbm = OTHER_BETA_L;
 	char* websmsru = WEBSMSRU_L;
+	char* exetel = EXETEL_L;
+	char* pennytel = PENNYTEL_L;
 
 	user_label = gtk_label_new ("Username");
 	pass_label = gtk_label_new ("Password");
 	number_label = gtk_label_new("Phone Number");
 	prov_label = gtk_label_new ("Provider");
-	proxy_label = gtk_label_new ("Use Web Proxy");
+	proxy_label = gtk_label_new ("Use Cabbage Web Proxy");
 	proxy_url_label = gtk_label_new ("Web Proxy Address (http://...");
 	done_label = gtk_label_new(
 		"Your settings are now configured. \nEnjoy using webtexter");
 	proxy_info_label = gtk_label_new(
-		"Send through the cabbage style web scripts.\nNote: These scripts are mainly aimed at Irish users.\nNever used for Blueface or Other Betamax");
+		"Send through the cabbage style web scripts.\nNote: These scripts are mainly aimed at Irish users.\nNever used for Blueface, websms.ru, Exetel \nPennyTel or Other Betamax");
 	url_info_label = gtk_label_new(
 		"For a named provider:\nif web proxy selected enter script address\nif web proxy not selected enter anything\nFor Other Betamax providers:\nplease enter the URL of the sms page. \nThis is normally in the format \nhttps://www.provider.com/myaccount/sendsms.php");
 	savemsg_label = gtk_label_new("Save sent messages:");
@@ -743,13 +794,22 @@ gint create_settings_wizard(AppData *appdata)
 	gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON(websmsru_button), FALSE);
 	hildon_gtk_widget_set_theme_size(websmsru_button, HILDON_SIZE_FINGER_HEIGHT);
 
+	exetel_button = hildon_gtk_radio_button_new_from_widget(HILDON_SIZE_AUTO , GTK_RADIO_BUTTON(websmsru_button));
+	gtk_button_set_label(GTK_BUTTON(exetel_button), exetel);
+	gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON(exetel_button), FALSE);
+	hildon_gtk_widget_set_theme_size(exetel_button, HILDON_SIZE_FINGER_HEIGHT);
+
+	pennytel_button = hildon_gtk_radio_button_new_from_widget(HILDON_SIZE_AUTO , GTK_RADIO_BUTTON(exetel_button));
+	gtk_button_set_label(GTK_BUTTON(pennytel_button), pennytel);
+	gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON(pennytel_button), FALSE);
+	hildon_gtk_widget_set_theme_size(pennytel_button, HILDON_SIZE_FINGER_HEIGHT);
 
 	yes_proxy = hildon_gtk_radio_button_new(HILDON_SIZE_AUTO , NULL);
-	gtk_button_set_label(GTK_BUTTON(yes_proxy), "Use Web Proxy");
+	gtk_button_set_label(GTK_BUTTON(yes_proxy), "Use Cabbage Web Proxy");
 	gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON(yes_proxy), FALSE);
 	hildon_gtk_widget_set_theme_size(yes_proxy, HILDON_SIZE_FINGER_HEIGHT);
 	no_proxy = hildon_gtk_radio_button_new_from_widget(HILDON_SIZE_AUTO , GTK_RADIO_BUTTON(yes_proxy));
-	gtk_button_set_label(GTK_BUTTON(no_proxy), "Don't use Web Proxy");
+	gtk_button_set_label(GTK_BUTTON(no_proxy), "Don't use Cabbage Web Proxy");
 	gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON(no_proxy), FALSE);
 	hildon_gtk_widget_set_theme_size(no_proxy, HILDON_SIZE_FINGER_HEIGHT);
 
@@ -833,6 +893,16 @@ gint create_settings_wizard(AppData *appdata)
 				gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(websmsru_button), TRUE);
 				break;
 			}
+			case EXETEL:
+			{
+				gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(exetel_button), TRUE);
+				break;
+			}
+			case PENNYTEL:
+			{
+				gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pennytel_button), TRUE);
+				break;
+			}
 		}
 	}
 	else
@@ -875,6 +945,8 @@ gint create_settings_wizard(AppData *appdata)
 	gtk_box_pack_start (GTK_BOX (prov_hbox), lowratevoip_button, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (prov_hbox), other_betamax_button, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (prov_hbox), websmsru_button, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (prov_hbox), exetel_button, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (prov_hbox), pennytel_button, FALSE, FALSE, 0);
 
 	hildon_pannable_area_add_with_viewport (
 	    HILDON_PANNABLE_AREA (prov_panable), prov_hbox);
